Struct graphql_client_codegen::GraphQLClientDeriveOptions [−][src]
pub struct GraphQLClientDeriveOptions {
pub struct_name: String,
pub additional_derives: Option<String>,
pub deprecation_strategy: Option<DeprecationStrategy>,
}Used to configure code generation.
Fields
struct_name: String
Name of the operation we want to generate code for. If it does not match, we default to the first one.
additional_derives: Option<String>
Comma-separated list of additional traits we want to derive.
deprecation_strategy: Option<DeprecationStrategy>
The deprecation strategy to adopt.